==> stefan-0.1.11-py3-none-any.whl: stefan/tool/tools_config.py <==
from stefan.tool.tool_create_file import CreateFileToolDefinition
from stefan.tool.tool_create_multiple_files import CreateMultipleFilesToolDefinition
from stefan.tool.tool_full_text_search import FullTextSearchToolDefinition
from stefan.tool.tool_full_text_with_relevancy_search import FullTextWithRelevancySearchToolDefinition
from stefan.tool.tool_read_file import ReadFileToolDefinition
from stefan.tool.tool_read_multiple_files import ReadMultipleFilesToolDefinition
from stefan.tool.tool_search_code import SearchCodeToolDefinition
from stefan.tool.tool_show_directory import ShowDirectoryToolDefinition
from stefan.tool.tool_write_file import WriteFileToolDefinition
from stefan.tool.tool_write_multiple_files import WriteMultipleFilesToolDefinition
from stefan.tool.tool_ask_followup_question import AskFollowupQuestionToolDefinition
from stefan.tool.tool_attempt_completion import AttemptCompletionToolDefinition

AVAILABLE_TOOLS = [
    CreateFileToolDefinition(),
    CreateMultipleFilesToolDefinition(),
    ReadFileToolDefinition(),
    ReadMultipleFilesToolDefinition(),
    ShowDirectoryToolDefinition(),
    WriteFileToolDefinition(),
    WriteMultipleFilesToolDefinition(),
    SearchCodeToolDefinition(),
    FullTextSearchToolDefinition(),
    FullTextWithRelevancySearchToolDefinition(),
    AskFollowupQuestionToolDefinition(),
    AttemptCompletionToolDefinition(),
]

PLANNER_TOOLS = [
    ReadFileToolDefinition(),
    ReadMultipleFilesToolDefinition(),
    ShowDirectoryToolDefinition(),
    SearchCodeToolDefinition(),
    FullTextSearchToolDefinition(),
    FullTextWithRelevancySearchToolDefinition(),
    AskFollowupQuestionToolDefinition(),
    AttemptCompletionToolDefinition(),
]

CODER_TOOLS = AVAILABLE_TOOLS

==> stefan-0.1.25-py3-none-any.whl: stefan/tool/tools_config.py <==
from stefan.tool.tool_create_file import CreateFileToolDefinition
from stefan.tool.tool_create_multiple_files import CreateMultipleFilesToolDefinition
from stefan.tool.tool_full_text_search import FullTextSearchToolDefinition
from stefan.tool.tool_full_text_with_relevancy_search import FullTextWithRelevancySearchToolDefinition
from stefan.tool.tool_read_file import ReadFileToolDefinition
from stefan.tool.tool_read_multiple_files import ReadMultipleFilesToolDefinition
from stefan.tool.tool_search_code import SearchCodeToolDefinition
from stefan.tool.tool_show_directory import ShowDirectoryToolDefinition
from stefan.tool.tool_write_file import WriteFileToolDefinition
from stefan.tool.tool_write_multiple_files import WriteMultipleFilesToolDefinition
from stefan.tool.tool_ask_followup_question import AskFollowupQuestionToolDefinition
from stefan.tool.tool_attempt_completion import AttemptCompletionToolDefinition

AVAILABLE_TOOLS = [
    CreateFileToolDefinition(),
    CreateMultipleFilesToolDefinition(),
    ReadFileToolDefinition(),
    ReadMultipleFilesToolDefinition(),
    ShowDirectoryToolDefinition(),
    WriteFileToolDefinition(),
    WriteMultipleFilesToolDefinition(),
    SearchCodeToolDefinition(),
    FullTextSearchToolDefinition(),
    FullTextWithRelevancySearchToolDefinition(),
    AttemptCompletionToolDefinition(),
    # AskFollowupQuestionToolDefinition(),
]

PLANNER_TOOLS = [
    ReadFileToolDefinition(),
    ReadMultipleFilesToolDefinition(),
    ShowDirectoryToolDefinition(),
    SearchCodeToolDefinition(),
    FullTextSearchToolDefinition(),
    FullTextWithRelevancySearchToolDefinition(),
    AttemptCompletionToolDefinition(),
    #AskFollowupQuestionToolDefinition(),
]

CODER_TOOLS = AVAILABLE_TOOLS
